@@ -2,7 +2,7 @@ package Minilla;
 use strict;
 use warnings;
 use 5.008005;
-use version; our $VERSION = version->declare("v3.0.3");
+use version; our $VERSION = version->declare("v3.0.4");
 
 our $DEBUG;
 our $AUTO_INSTALL;
@@ -197,9 +197,9 @@ See L<CPAN::Meta::Spec>.
 
 =item badges
 
-    badges = ['travis', 'appveyor', 'coveralls', 'codecov', 'gitter']
+    badges = ['travis', 'circleci', 'appveyor', 'coveralls', 'codecov', 'gitter']
 
-Embed badges image (e.g. Travis-CI) to README.md. It ought to be array and each elements must be service name. Now, supported services are only 'travis', 'appveyor', 'coveralls', 'codecov' and 'gitter'.
+Embed badges image (e.g. Travis-CI) to README.md. It ought to be array and each elements must be service name. Now, supported services are only 'travis', 'circleci', 'appveyor', 'coveralls', 'codecov' and 'gitter'.
 
 =item PL_files
 
